@@ -132,7 +132,7 @@ class SmartPy:
         return True, ""
 
     def runAllTests(self):
-        tests = glob.iglob("./tests/*.smartpy.py")
+        tests = glob.iglob("./tests/*_smartpy.py")
         status = 0
         for test in tests:
             if self.runSingleTest(test):
@@ -260,21 +260,22 @@ class SmartPy:
         targetPath = pathlib.Path(f"{os.getcwd()}")
 
         helpers.copyFile(
-                f"{chinstrapPath}/core/sources/contracts/FA1.2.py",
-                f"{targetPath}/contracts/FA1.2.py",
-            )
+            f"{chinstrapPath}/core/sources/contracts/FA1.2.py",
+            f"{targetPath}/contracts/FA1.2.py",
+        )
 
         helpers.copyFile(
-                f"{chinstrapPath}/core/sources/originations/1_FA12_origination.py",
-                f"{targetPath}/originations/1_FA12_origination.py",
-            )
+            f"{chinstrapPath}/core/sources/originations/1_FA12_origination.py",
+            f"{targetPath}/originations/1_FA12_origination.py",
+        )
 
         helpers.copyFile(
-                f"{chinstrapPath}/core/sources/tests/FA1.2.smartpy.py",
-                f"{targetPath}/tests/FA1.2.smartpy.py",
-            )
-        
-        spinner.succeed(text=f"Creatied FA.1.2 templates!")
+            f"{chinstrapPath}/core/sources/tests/FA1.2.smartpy.py",
+            f"{targetPath}/tests/FA1.2.smartpy.py",
+        )
+
+        spinner.succeed(text="Creatied FA.1.2 templates!")
+
 
 class SmartPyDownloader:
     def __init__(self):
